/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.strategy;

import com.yiring.app.domain.location.LocationFenceAlarm;
import com.yiring.app.param.location.fence.LocationFenceJobParam;
import com.yiring.app.vo.location.fence.LocationFenceJobVo;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import org.springframework.util.CollectionUtils;

/**
 * 扫描是否满足报警策略
 * @author tml
 * @version 1.0
 * @date 2022/5/14 11:05
 */
@FunctionalInterface
public interface IScanAlarmStrategy {
    /**
     * 判断是否触发报警
     * @param param 参数
     * @return 需要报警的报警信息
     */
    LocationFenceJobVo scanAlarm(LocationFenceJobParam param);

    /**
     * 将两个集合不相交的部分筛选出来，并封装到结果集
     * @param newAlarms 集合1
     * @param oldAlarms 集合2
     * @param jobVo 结果集
     */
    static void notIntersect(
        List<LocationFenceAlarm> newAlarms,
        List<LocationFenceAlarm> oldAlarms,
        LocationFenceJobVo jobVo
    ) {
        if (!CollectionUtils.isEmpty(oldAlarms)) {
            Set<Long> newSet = newAlarms.stream().map(e -> e.getTag().getId()).collect(Collectors.toSet());
            Set<Long> oldSet = oldAlarms.stream().map(e -> e.getTag().getId()).collect(Collectors.toSet());
            newAlarms =
                newAlarms.stream().filter(e -> !oldSet.contains(e.getTag().getId())).collect(Collectors.toList());
            oldAlarms =
                oldAlarms.stream().filter(e -> !newSet.contains(e.getTag().getId())).collect(Collectors.toList());
        }
        jobVo.setAddAlarm(newAlarms);
        jobVo.setModifyAlarm(oldAlarms);
    }
}
