/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.risk;

import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.constant.risk.ThresholdStatusEnum;
import com.yiring.app.domain.risk.RiskWarn;
import com.yiring.app.domain.risk.Threshold;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.util.CollectionUtils;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/24 11:17
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ExcelModel
public class RiskWarnExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = -535906627975355631L;

    @ExcelColumn(title = "工区", width = 15)
    private String workAreaName;

    @ExcelColumn(title = "安装位置", width = 15)
    private String install;

    @ExcelColumn(title = "经纬度", width = 30)
    private String point;

    @ExcelColumn(title = "监控参数", width = 15)
    private String monitoring;

    @ExcelColumn(title = "位号", width = 10)
    private String locationNum;

    @ExcelColumn(title = "量程", width = 10)
    private String range;

    @ExcelColumn(title = "量程单位", width = 10)
    private String unit;

    @ExcelColumn(title = "报警值(低低)", width = 10)
    private String lowLow;

    @ExcelColumn(title = "报警值(低)", width = 10)
    private String low;

    @ExcelColumn(title = "报警值(高)", width = 10)
    private String high;

    @ExcelColumn(title = "报警值(高高)", width = 10)
    private String highHigh;

    @ExcelColumn(title = "报警值(熄灭)", width = 10)
    private String flame;

    @ExcelColumn(title = "备注", width = 40)
    private String remark;

    public static RiskWarnExcel transform(RiskWarn riskWarn) {
        String range = "";
        if (riskWarn.getMin() != null && riskWarn.getMax() != null) {
            range = riskWarn.getMin() + "-" + riskWarn.getMax();
        }
        String point =
            riskWarn.getPoint().getCoordinate().getX() +
            "," +
            riskWarn.getPoint().getCoordinate().getY() +
            "," +
            riskWarn.getPoint().getCoordinate().getZ();
        Map<Integer, List<Threshold>> map = riskWarn
            .getThresholds()
            .stream()
            .collect(Collectors.groupingBy(Threshold::getStatus));
        List<Threshold> lowLowList = map.get(ThresholdStatusEnum.LOW_LOW.getCode());
        List<Threshold> lowList = map.get(ThresholdStatusEnum.LOW.getCode());
        List<Threshold> highList = map.get(ThresholdStatusEnum.HIGH.getCode());
        List<Threshold> highHighList = map.get(ThresholdStatusEnum.HIGH_HIGH.getCode());
        List<Threshold> flameList = map.get(ThresholdStatusEnum.FLAME_EXTINGUISH.getCode());
        String lowLow = CollectionUtils.isEmpty(lowLowList) ? "" : lowLowList.get(0).getMin();
        String low = CollectionUtils.isEmpty(lowList) ? "" : lowList.get(0).getMin();
        String high = CollectionUtils.isEmpty(highList) ? "" : highList.get(0).getMin();
        String highHigh = CollectionUtils.isEmpty(highHighList) ? "" : highHighList.get(0).getMin();
        String flame = CollectionUtils.isEmpty(flameList) ? "" : flameList.get(0).getMin();
        return RiskWarnExcel
            .builder()
            .workAreaName(riskWarn.getWorkArea().getWorkAreaName())
            .point(point)
            .install(riskWarn.getInstall())
            .monitoring(riskWarn.getMonitoring())
            .locationNum(riskWarn.getLocationNum())
            .range(range)
            .unit(riskWarn.getUnit())
            .lowLow(lowLow)
            .low(low)
            .high(high)
            .highHigh(highHigh)
            .flame(flame)
            .build();
    }
}
