/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.risk;

import com.yiring.app.domain.risk.RiskWarn;
import com.yiring.app.domain.risk.Threshold;
import com.yiring.app.domain.workArea.WorkArea;
import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;
import java.util.stream.Collectors;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import lombok.Data;
import org.locationtech.jts.geom.Point;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/23 15:04
 */
@ApiModel("风险预警管理")
@Data
public class RiskWarnAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -322828089862736394L;

    @ApiModelProperty(value = "所属工区id", example = "1", required = true)
    @NotNull(message = "工区不能为空")
    private Long workAreaId;

    @ApiModelProperty(value = "安装位置", example = "组件厂区二楼", required = true)
    @NotNull(message = "安装位置不能为空")
    private String install;

    @ApiModelProperty(value = "经纬度", required = true, dataType = "java.lang.String")
    @NotNull(message = "经纬度不能为空")
    private Point point;

    @ApiModelProperty(value = "监控参数", example = "有毒气体报警器", required = true)
    @NotNull(message = "监控参数不能为空")
    private String monitoring;

    @ApiModelProperty(value = "位号", example = "AT-4736", required = true)
    @NotNull(message = "位号不能为空")
    private String locationNum;

    @ApiModelProperty(value = "量程起始值", example = "1.3")
    @Pattern(regexp = RegEx.DIGIT_DECIMALS, message = "量程的数字格式不正确,只能为整数或小数")
    private BigDecimal min;

    @ApiModelProperty(value = "量程结束值", example = "50.2")
    @Pattern(regexp = RegEx.DIGIT_DECIMALS, message = "量程的数字格式不正确,只能为整数或小数")
    private BigDecimal max;

    @ApiModelProperty(value = "量程单位", example = "ppm")
    private String unit;

    private List<ThresholdParam> thresholds;

    public RiskWarn transform() {
        WorkArea workArea = new WorkArea();
        workArea.setId(workAreaId);
        List<Threshold> list = thresholds.stream().map(ThresholdParam::transform).collect(Collectors.toList());
        return RiskWarn
            .builder()
            .workArea(workArea)
            .install(install)
            .point(point)
            .monitoring(monitoring)
            .locationNum(locationNum)
            .min(min)
            .max(max)
            .unit(unit)
            .enable(true)
            .thresholds(list)
            .build();
    }
}
