/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.risk;

import com.yiring.app.param.risk.RiskWarnAddParam;
import com.yiring.app.param.risk.RiskWarnConditionParam;
import com.yiring.app.param.risk.RiskWarnModifyParam;
import com.yiring.app.vo.risk.RiskWarnDetailVo;
import com.yiring.app.vo.risk.RiskWarnVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.Set;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/23 17:42
 */
public interface RiskWarnService {
    /**
     * 添加一条
     * @param param 风险预警信息
     * @return 是否成功
     */
    Result<String> addOne(@Valid RiskWarnAddParam param);

    /**
     * 修改一条
     * @param param 风险预警信息
     * @return 是否成功
     */
    Result<String> modifyOne(@Valid RiskWarnModifyParam param);

    /**
     * 删除一条
     * @param idParam id
     * @return 是否成功
     */
    Result<String> removeOne(@Valid IdParam idParam);

    /**
     * 查询一条
     * @param idParam id
     * @return 风险预警详细信息
     */
    Result<RiskWarnDetailVo> findOne(@Valid IdParam idParam);

    /**
     * 查询列表
     * @param conditionParam 条件
     * @param pageParam 分页参数
     * @return 列表
     */
    Result<PageVo<RiskWarnVo>> findList(@Valid RiskWarnConditionParam conditionParam, @Valid PageParam pageParam);

    /**
     * 导出
     * @param conditionParam 条件
     * @param response response
     */
    void exportRiskWarn(@Valid RiskWarnConditionParam conditionParam, HttpServletResponse response);

    /**
     * 导入
     * @param file excel文件
     * @return 是否成功
     */
    Result<String> importRiskWarn(MultipartFile file);

    /**
     * 导出模板
     * @param response response
     */
    void exportTemplate(HttpServletResponse response);

    /**
     * 批量启用或停用
     * @param ids ids
     * @param enable 启用:true-启用,false-停用
     * @return 是否成功
     */
    Result<String> batchEnable(Set<Long> ids, boolean enable);
}
