/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.district;

import com.yiring.app.domain.district.District;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/19 16:02
 */
@ApiModel("区域信息")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class DistrictDetailsVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 3900485837172743182L;

    @ApiModelProperty(value = "区域id", example = "1")
    private Long id;

    @ApiModelProperty(value = "区域名称", example = "生产区域")
    private String name;

    @ApiModelProperty(value = "风险等级(区域颜色)", example = "f##0000")
    private String riskGrade;

    @ApiModelProperty(value = "空间信息", dataType = "java.lang.String")
    private Geometry geometry;

    @ApiModelProperty(value = "地图id", example = "1")
    private Integer mapId;

    public static DistrictDetailsVo transform(District district) {
        return DistrictDetailsVo
            .builder()
            .id(district.getId())
            .name(district.getName())
            .riskGrade(district.getRiskGrade())
            .geometry(district.getGeometry())
            .mapId(builder().mapId)
            .build();
    }
}
