/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.fence;

import com.yiring.app.constant.alarm.InformMannerEnum;
import com.yiring.app.constant.alarm.ReceiveStatusEnum;
import com.yiring.app.domain.location.FenceAlarmPushLog;
import io.swagger.annotations.ApiModel;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.Comment;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/18 9:56
 */
@ApiModel("围栏报警推送记录")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class FenceAlarmPushLogVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 4628469269093052929L;

    @Comment("报警接受人")
    private String name;

    @Comment("联系电话")
    private String phone;

    @Comment("通知方式: 1-app消息 2-短信通知 3-电话通知")
    private String informManner;

    @Comment("通知状态: 1-成功 2-失败")
    private String status;

    @Comment("接受时间")
    private LocalDateTime time;

    public static FenceAlarmPushLogVo transform(FenceAlarmPushLog pushLog) {
        return FenceAlarmPushLogVo
            .builder()
            .name(pushLog.getUser().getRealName() + "(" + pushLog.getUser().getDepartment().getName() + ")")
            .phone(pushLog.getUser().getMobile())
            .informManner(InformMannerEnum.getByCode(pushLog.getInformManner()))
            .status(ReceiveStatusEnum.getByCode(pushLog.getStatus()))
            .time(pushLog.getTime())
            .build();
    }
}
