/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.fence;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.domain.location.LocationFence;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/20 9:11
 */
@ApiModel("围栏实时数据")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class FenceRealtimeVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 5364975855865067076L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "围栏id", example = "1527096652123344896")
    private Long id;

    @ApiModelProperty(value = "围栏名称", example = "一号围栏")
    private String name;

    @ApiModelProperty(value = "地图id", example = "1")
    private Integer mapId;

    @ApiModelProperty(value = "地图名称", example = "总图")
    private String mapName;

    @ApiModelProperty(value = "围栏类别:1-普通围栏,2-特殊作业,3-重大危险源", example = "1")
    private Integer fenceType;

    @ApiModelProperty(value = "围栏类别名称", example = "普通围栏")
    private String fenceTypeName;

    @ApiModelProperty(value = "空间信息", dataType = "java.lang.String")
    private Geometry geometry;

    public static FenceRealtimeVo transform(LocationFence fence) {
        return FenceRealtimeVo
            .builder()
            .id(fence.getId())
            .name(fence.getName())
            .mapId(fence.getMapId().intValue())
            .mapName(fence.getMapName())
            .fenceType(fence.getFenceType())
            .fenceTypeName(FenceTypeEnum.getByCode(fence.getFenceType()))
            .geometry(fence.getGeometry())
            .build();
    }
}
