/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.fence;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.location.LocationFence;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/26 9:08
 */
@ApiModel("电子围栏地图信息")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class LocationFenceGeoVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 7736396772271720214L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id")
    private Long id;

    @ApiModelProperty(value = "type")
    private String type;

    @ApiModelProperty("properties")
    private Properties properties;

    @ApiModelProperty(value = "位置信息")
    private Geometry geometry;

    public static LocationFenceGeoVo transform(LocationFence locationFence) {
        return LocationFenceGeoVo
            .builder()
            .id(locationFence.getId())
            .type("Feature")
            .properties(
                new Properties(
                    locationFence.getId(),
                    locationFence.getName(),
                    locationFence.getGeometry().getGeometryType()
                )
            )
            .geometry(locationFence.getGeometry())
            .build();
    }

    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    static class Properties {

        @JsonSerialize(using = ToStringSerializer.class)
        @ApiModelProperty(value = "id")
        private Long id;

        @ApiModelProperty(value = "围栏名称")
        private String name;

        @ApiModelProperty(value = "位置类型")
        private String type;
    }
}
