/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.station;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.util.GeoUtils;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;
import org.locationtech.jts.geom.Point;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/17 10:41
 */
@ApiModel("LocationBaseStationVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationBaseStationVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 2580621691725484516L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "188354391834")
    Long id;

    @ApiModelProperty(value = "编号", example = "BTI88888888")
    String deviceId;

    @ApiModelProperty(value = "类型", example = "BTI88888888")
    String deviceType;

    @ApiModelProperty(value = "最后一次在线时间", example = "BTI88888888")
    LocalDateTime time;

    @ApiModelProperty(value = "坐标", example = "01010000805C8FC2F528D4734033333333335B7D400000000000000000")
    Point point;

    public Point getPoint() {
        if (x != null && y != null && z != null) {
            return GeoUtils.xyzToPoint(x, y, z);
        }
        return null;
    }

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "所属地图id", example = "1:总图2:一层3:二层")
    Long areaId;

    @ApiModelProperty(value = "所属地图", example = "1:总图2:一层3:二层")
    String areaName;

    @ApiModelProperty(value = "电量单位", example = "")
    String voltUnit;

    Double x;

    Double y;

    Double z;
}
