/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.risk;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.risk.RiskWarn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/23 15:40
 */
@ApiModel("风险预警管理")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class RiskWarnVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 6006976424270409054L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id", example = "1")
    private Long id;

    @ApiModelProperty(value = "工区名称", example = "组装工区")
    private String workAreaName;

    @ApiModelProperty(value = "安装位置", example = "组装厂区二楼")
    private String install;

    @ApiModelProperty(value = "监控参数", example = "有毒气体报警器")
    private String monitoring;

    @ApiModelProperty(value = "位号", example = "AT-4736")
    private String locationNum;

    @ApiModelProperty(value = "量程", example = "0-100PPm")
    private String range;

    @ApiModelProperty(value = "是否启用", example = "true")
    private Boolean enable;

    public static RiskWarnVo transform(RiskWarn riskWarn) {
        String range = riskWarn.getMin().toString() + "-" + riskWarn.getMax().toString();
        return RiskWarnVo
            .builder()
            .id(riskWarn.getId())
            .workAreaName(riskWarn.getWorkArea().getWorkAreaName())
            .install(riskWarn.getInstall())
            .monitoring(riskWarn.getMonitoring())
            .locationNum(riskWarn.getLocationNum())
            .range(range)
            .enable(riskWarn.getEnable())
            .build();
    }
}
