/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.risk;

import com.yiring.app.constant.rehearsal.RiskLevelEnum;
import com.yiring.app.constant.risk.ThresholdStatusEnum;
import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.param.risk.RiskWarnAddParam;
import com.yiring.app.param.risk.RiskWarnConditionParam;
import com.yiring.app.param.risk.RiskWarnModifyParam;
import com.yiring.app.service.risk.RiskWarnService;
import com.yiring.app.vo.CodeNameVo;
import com.yiring.app.vo.risk.RiskWarnDetailVo;
import com.yiring.app.vo.risk.RiskWarnVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import java.util.Objects;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import org.springframework.data.domain.Sort;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/23 17:16
 */
@Api(tags = "风险预警管理")
@Validated
@RestController
@RequestMapping("/risk/warn")
public class RiskWarnController {

    @Resource
    private RiskWarnService riskWarnService;

    @ApiOperation("添加一条")
    @PostMapping("/addOne")
    public Result<String> addOne(@Valid RiskWarnAddParam param) {
        return riskWarnService.addOne(param);
    }

    @ApiOperation("修改一条")
    @PostMapping("/modifyOne")
    public Result<String> modifyOne(@Valid RiskWarnModifyParam param) {
        return riskWarnService.modifyOne(param);
    }

    @ApiOperation("删除一条")
    @PostMapping("/removeOne")
    public Result<String> removeOne(@Valid IdParam idParam) {
        return riskWarnService.removeOne(idParam);
    }

    @ApiOperation("查询一条")
    @GetMapping("/findOne")
    public Result<RiskWarnDetailVo> findOne(@Valid IdParam idParam) {
        return riskWarnService.findOne(idParam);
    }

    @ApiOperation("查询列表")
    @GetMapping("/findList")
    public Result<PageVo<RiskWarnVo>> findList(
        @Valid RiskWarnConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        if (Objects.isNull(pageParam.getSortField())) {
            pageParam.setSortField(AlarmType.Fields.createTime);
            pageParam.setSortOrder(Sort.Direction.DESC);
        }
        return riskWarnService.findList(conditionParam, pageParam);
    }

    @ApiOperation("查询阈值状态下拉框")
    @GetMapping("/findThresholds")
    public Result<PageVo<CodeNameVo>> findThresholds() {
        List<CodeNameVo> list = ThresholdStatusEnum.getAll();
        PageVo<CodeNameVo> pageVo = PageVo.build(list, list.size());
        return Result.ok(pageVo);
    }

    @ApiOperation("查询风险等级下拉框")
    @GetMapping("/findRiskLevels")
    public Result<PageVo<CodeNameVo>> findRiskLevels() {
        List<CodeNameVo> list = RiskLevelEnum.getAll();
        PageVo<CodeNameVo> pageVo = PageVo.build(list, list.size());
        return Result.ok(pageVo);
    }

    @ApiOperation(value = "导出", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @GetMapping("/exportRiskWarn")
    public void exportRiskWarn(@Valid RiskWarnConditionParam conditionParam, HttpServletResponse response) {
        riskWarnService.exportRiskWarn(conditionParam, response);
    }

    @ApiOperation("导入")
    @PostMapping("/importRiskWarn")
    public Result<String> importRiskWarn(MultipartFile file) {
        return riskWarnService.importRiskWarn(file);
    }

    @ApiOperation(value = "导出模板", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @GetMapping("/exportTemplate")
    public void exportTemplate(HttpServletResponse response) {
        riskWarnService.exportTemplate(response);
    }

    @ApiOperation("批量启用或停用")
    @ApiImplicitParam(value = "启用:true-启用,false-停用", required = true)
    @PostMapping("/batchEnable")
    public Result<String> batchEnable(@Valid IdsParam idsParam, boolean enable) {
        return riskWarnService.batchEnable(idsParam.toIds(), enable);
    }
}
