/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.warningMsg;

import com.yiring.app.param.warningMsg.WarningMessageParam;
import com.yiring.app.param.warningMsg.WarningMessageQueryParam;
import com.yiring.app.service.warningMsg.WarningMessageService;
import com.yiring.app.vo.warningMsg.WarningMessageCountVo;
import com.yiring.app.vo.warningMsg.WarningMessageRecVo;
import com.yiring.app.vo.warningMsg.WarningMessageVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/23 15:02
 */
@Slf4j
@Validated
@SuppressWarnings({ "deprecation" })
@Api(tags = "预警", description = "WarningMessage")
@RestController
@RequestMapping("/warningMessage/")
public class WarningMessageController {

    @Resource
    WarningMessageService warningMessageService;

    @ApiOperation(value = "通知处置预警信息")
    @PostMapping("update")
    public Result<String> update(@Valid WarningMessageParam warningMessageParam, @Valid IdParam idParam) {
        return warningMessageService.update(warningMessageParam, idParam);
    }

    @ApiOperation(value = "删除预警信息")
    @PostMapping("delete")
    public Result<String> delete(@Valid IdParam idParam) {
        return warningMessageService.delete(idParam);
    }

    @ApiOperation(value = "查看预警信息")
    @GetMapping("page")
    public Result<PageVo<WarningMessageVo>> page(@Valid WarningMessageQueryParam warningMessageQueryParam) {
        return warningMessageService.page(warningMessageQueryParam);
    }

    @ApiOperation(value = "统计预警信息")
    @GetMapping("list")
    public Result<PageVo<WarningMessageCountVo>> list(@Valid WarningMessageQueryParam warningMessageQueryParam) {
        return warningMessageService.list(warningMessageQueryParam);
    }

    @ApiOperation(value = "统计预警信息")
    @GetMapping("listRec")
    public Result<PageVo<WarningMessageRecVo>> listRec(@Valid IndexParam indexParam) {
        return warningMessageService.listRec(indexParam);
    }

    @ApiOperation(value = "导出预警信息", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("export")
    public void export(HttpServletResponse response, @Valid WarningMessageQueryParam warningMessageQueryParam) {
        warningMessageService.export(warningMessageQueryParam, response);
    }
}
