/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.service.user;

import com.yiring.auth.param.user.*;
import com.yiring.auth.vo.user.UserVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;

/**
 * 用户
 *
 * @author LJ-2204
 * @date 2022/5/10
 */
public interface UserService {
    /**
     * 添加系统用户
     * @param param UserSaveParam
     * @return Result<String>
     */
    Result<String> add(UserSaveParam param);

    /**
     * 分页查询
     * @param param UserFindParam
     * @param pageParam PageParam
     * @return Result<PageVo<UserVo>>
     */
    Result<PageVo<UserVo>> page(UserFindParam param, PageParam pageParam);

    /**
     * 重置密码
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> reset(IdParam idParam);

    /**
     * 修改状态
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> upStatus(IdParam idParam);

    /**
     * 导出
     * @param param UserExportParam
     * @param response HttpServletResponse
     */
    void export(UserExportParam param, HttpServletResponse response);

    /**
     * 修改密码
     * @param param UserPwdParam
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> modifyPwd(UserPwdParam param, IdParam idParam);

    /**
     * 修改手机号
     * @param param UserPhoneParam
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> modifyPhone(UserPhoneParam param, IdParam idParam);

    /**
     * 发送验证码
     * @param param UserPhoneParam
     * @return Result<String>
     */
    Result<String> sendCode(UserPhoneParam param);

    /**
     * 通过手机验证码修改密码
     * @param userPwdParam UserPwdParam
     * @param userPhoneParam UserPhoneParam
     * @return Result<String>
     */
    Result<String> modifyPwdByPhone(UserPwdParam userPwdParam, UserPhoneParam userPhoneParam);
}
